@@ -1,7 +1,7 @@
 /*****************************************************************************
  * decode_pat.c: PAT decoder example
  *----------------------------------------------------------------------------
- * Copyright (C) 2001-2010 VideoLAN
+ * Copyright (C) 2001-2011 VideoLAN
  * $Id$
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -24,11 +24,11 @@
  *
  *****************************************************************************/
 
-
 #include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdbool.h>
 #include <unistd.h>
 #include <fcntl.h>
 
@@ -49,11 +49,10 @@
 #include <dvbpsi/pat.h>
 #endif
 
-
 /*****************************************************************************
  * ReadPacket
  *****************************************************************************/
-static int ReadPacket(int i_fd, uint8_t* p_dst)
+static bool ReadPacket(int i_fd, uint8_t* p_dst)
 {
   int i = 187;
   int i_rc = 1;
@@ -72,7 +71,7 @@ static int ReadPacket(int i_fd, uint8_t* p_dst)
       i -= i_rc;
   }
 
-  return (i == 0) ? 1 : 0;
+  return (i == 0) ? true : false;
 }
 
 
@@ -94,9 +93,21 @@ static void DumpPAT(void* p_zero, dvbpsi_pat_t* p_pat)
     p_program = p_program->p_next;
   }
   printf(  "  active              : %d\n", p_pat->b_current_next);
-  dvbpsi_DeletePAT(p_pat);
+  dvbpsi_pat_delete(p_pat);
 }
 
+static void message(dvbpsi_t *handle, const dvbpsi_msg_level_t level, const char* msg)
+{
+    switch(level)
+    {
+        case DVBPSI_MSG_ERROR: fprintf(stderr, "Error: "); break;
+        case DVBPSI_MSG_WARN:  fprintf(stderr, "Warning: "); break;
+        case DVBPSI_MSG_DEBUG: fprintf(stderr, "Debug: "); break;
+        default: /* do nothing */
+            return;
+    }
+    fprintf(stderr, "%s\n", msg);
+}
 
 /*****************************************************************************
  * main
@@ -105,15 +116,22 @@ int main(int i_argc, char* pa_argv[])
 {
   int i_fd;
   uint8_t data[188];
-  dvbpsi_handle h_dvbpsi;
-  int b_ok;
+  dvbpsi_t *p_dvbpsi;
+  bool b_ok;
 
-  if(i_argc != 2)
-    return 1;
+  if (i_argc != 2)
+      return 1;
 
   i_fd = open(pa_argv[1], 0);
+  if (i_fd < 0)
+      return 1;
 
-  h_dvbpsi = dvbpsi_AttachPAT(DumpPAT, NULL);
+  p_dvbpsi = dvbpsi_new(&message, DVBPSI_MSG_DEBUG);
+  if (p_dvbpsi == NULL)
+      goto out;
+
+  if (!dvbpsi_pat_attach(p_dvbpsi, DumpPAT, NULL))
+      goto out;
 
   b_ok = ReadPacket(i_fd, data);
 
@@ -121,11 +139,17 @@ int main(int i_argc, char* pa_argv[])
   {
     uint16_t i_pid = ((uint16_t)(data[1] & 0x1f) << 8) + data[2];
     if(i_pid == 0x0)
-      dvbpsi_PushPacket(h_dvbpsi, data);
+      dvbpsi_packet_push(p_dvbpsi, data);
     b_ok = ReadPacket(i_fd, data);
   }
 
-  dvbpsi_DetachPAT(h_dvbpsi);
+out:
+  if (p_dvbpsi)
+  {
+    dvbpsi_pat_detach(p_dvbpsi);
+    dvbpsi_delete(p_dvbpsi);
+  }
+  close(i_fd);
 
   return 0;
 }
