@@ -116,7 +116,7 @@ static void PATCallback( void *_unused, dvbpsi_pat_t *p_pat )
         return;
     }
 
-    for( p_program = p_pat->p_first_program; p_program != NULL;
+    for( p_program = p_pat->p_first_program; p_program != NULL && i_nb_programs < MAX_PROGRAMS;
          p_program = p_program->p_next )
     {
         if( p_program->i_number != 0
@@ -156,8 +156,13 @@ static void TSHandle( uint8_t *p_ts )
 
     if ( !ts_CheckSync( p_ts ) )
     {
-        fprintf( stderr, "lost TS synchro, go and fix your file (pos=%ju)\n",
-                 (uintmax_t)i_ts_read * TS_SIZE );
+        fprintf( stderr, "lost TS synchro, go and fix your file "
+#if defined(WIN32)
+                 " (pos=%u)\n",  (uint32_t) i_ts_read * TS_SIZE
+#else
+                 " (pos=%ju)\n", (uintmax_t)i_ts_read * TS_SIZE
+#endif
+	);
         exit(EXIT_FAILURE);
     }
 
