@@ -70,7 +70,7 @@ dvbpsi_component_dr_t* dvbpsi_DecodeComponentDr(dvbpsi_descriptor_t * p_descript
     if (p_descriptor->i_length > 6)
     {
     	p_decoded->i_text_length = p_descriptor->i_length - 6;
-    	p_decoded->i_text = calloc(p_decoded->i_text_length - 6, sizeof(uint8_t));
+        p_decoded->i_text = calloc(1, p_decoded->i_text_length);
         if (!p_decoded->i_text)
         {
         	free(p_decoded);
