@@ -323,14 +323,12 @@ void dvbpsi_cat_sections_gather(dvbpsi_t *p_dvbpsi,
         /* Decode the sections */
         dvbpsi_cat_sections_decode(p_cat_decoder->p_building_cat,
                                    p_cat_decoder->p_sections);
-        /* Delete the sections */
-        dvbpsi_DeletePSISections(p_cat_decoder->p_sections);
-        p_cat_decoder->p_sections = NULL;
         /* signal the new CAT */
         p_cat_decoder->pf_cat_callback(p_cat_decoder->p_cb_data,
                                        p_cat_decoder->p_building_cat);
-        /* Reinitialize the structures */
+        /* Delete sections and Reinitialize the structures */
         dvbpsi_ReInitCAT(p_cat_decoder, false);
+        assert(p_cat_decoder->p_sections == NULL);
     }
 }
 
@@ -347,7 +345,7 @@ void dvbpsi_cat_sections_decode(dvbpsi_cat_t* p_cat, dvbpsi_psi_section_t* p_sec
     {
         /* CAT descriptors */
         p_byte = p_section->p_payload_start;
-        while (p_byte + 5 <= p_section->p_payload_end)
+        while (p_byte <= p_section->p_payload_end)
         {
             uint8_t i_tag = p_byte[0];
             uint8_t i_length = p_byte[1];
