@@ -338,7 +338,8 @@ void dvbpsi_pmt_sections_gather(dvbpsi_t *p_dvbpsi, dvbpsi_psi_section_t* p_sect
     if (p_pmt_decoder->i_program_number != p_section->i_extension)
     {
         /* Invalid program_number */
-        dvbpsi_error(p_dvbpsi, "PMT decoder", "'program_number' don't match");
+        dvbpsi_debug(p_dvbpsi, "PMT decoder", "ignoring section %d not belonging to 'program_number' %d",
+                     p_section->i_extension, p_pmt_decoder->i_program_number);
         dvbpsi_DeletePSISections(p_section);
         return;
     }
@@ -393,14 +394,12 @@ void dvbpsi_pmt_sections_gather(dvbpsi_t *p_dvbpsi, dvbpsi_psi_section_t* p_sect
         /* Decode the sections */
         dvbpsi_pmt_sections_decode(p_pmt_decoder->p_building_pmt,
                                    p_pmt_decoder->p_sections);
-        /* Delete the sections */
-        dvbpsi_DeletePSISections(p_pmt_decoder->p_sections);
-        p_pmt_decoder->p_sections = NULL;
         /* signal the new PMT */
         p_pmt_decoder->pf_pmt_callback(p_pmt_decoder->p_cb_data,
                                        p_pmt_decoder->p_building_pmt);
-        /* Reinitialize the structures */
+        /* Delete sections and Reinitialize the structures */
         dvbpsi_ReInitPMT(p_pmt_decoder, false);
+        assert(p_pmt_decoder->p_sections == NULL);
     }
 }
 
